#!/bin/sh
# Run HALCON phyCAM scripts on your Arm-based Linux computer.
# Copyright (C) 2019 PHYTEC, Mainz, Germany

platform=$(uname -m)
case "$platform" in
  aarch64)
    arch="aarch64-linux"
  ;;
  armv7l)
    arch="armv7a-linux"
  ;;
  x86_64)
    echo "HPeek is available for Arm-based platforms only." >&2
    echo "" >&2
    exit 1
  ;;
  *)
    echo "Your platform $platform is not supported." >&2
    echo "" >&2
    exit 1
  ;;
esac

echo ""
echo " If the first start after reboot, an initialize of media-ctl is necessary"
echo " ========================================================================"
echo " 1 = monochrome camera @ Cam_0 (phyCAM-P/-S) port"
echo " 2 = color camera @ CAM_0 (phyCAM-P/-S) port"
echo " 3 = monochrome camera @ Cam_2 (phyCAM-M) port"
echo " 4 = color camera @ CAM_2 (phyCAM-M) port"
echo " 5 = initialize done"
read SET_MEDIA_CTL
echo " Your select = $SET_MEDIA_CTL"
case $SET_MEDIA_CTL in
  "1") ./init_bw_phyCAM_v4l_device.sh ;;
  "2") ./init_col_phyCAM_v4l_device.sh ;;
  "3") ./init_bw_phyCAM-M_v4l_device.sh ;;
  "4") ./init_col_phyCAM-M_v4l_device.sh ;;
  "5") ;;
  *) ;;
esac

if [ ! -f "camera_device.txt" ]; then
  echo " Could not find camera_device.txt." >&2
  echo " Please initialized you connected camera." >&2
  echo " Check if the connected camera is activated in the bootloader?" >&2
  echo "" >&2
  exit 1
fi

echo " Choose the example script"
echo " ========================="
echo " 1 = show live stream"
echo " 2 = save a jpg image"
echo " 3 = optical flow"
echo " 4 = show v4l2 interface parameter"
read SET_MEDIA_CTL
echo " Your select = $SET_MEDIA_CTL"
case $SET_MEDIA_CTL in
  "1") script=phyCAM_show_stream.hdev ;;
  "2") script=phyCAM_save_jpg.hdev ;;
  "3") script=optical_flow.hdev ;;
  "4") script=video4linux2_parameters.hdev ;;
  *) script=phyCAM_show_stream.hdev ;;
esac

if [ ! -f $script ]; then
  echo " Could not find '$script'." >&2
  echo " Please change to the HALCON examples/phytec directory and run ./start.sh there." >&2
  echo "" >&2
  exit 1
fi

source ./init_display.sh

echo " Running '../../bin/$arch/hpeek $script'"
../../bin/$arch/hpeek $script
